(contribution-guide)=

# Contributing

Contributions to gcell are welcome!
This section of the docs provides some guidelines and tips to follow when contributing.

```{toctree}
code
getting-set-up
testing
documentation
versioning
release
```

Parts of the guidelines have been adapted from the [pandas](https://pandas.pydata.org/pandas-docs/stable/development/index.html) and [MDAnalysis](https://userguide.mdanalysis.org/stable/contributing.html) guides.
These are both excellent guides and we highly recommend checking them out.
